///File : Printing.cpp
//------------------------------------------------------------------------------
/*
    This file is part of forbidden2forget.

    Forbidden2forget is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Forbidden2forget is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with forbidden2forget.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "Printing.hpp"
#include "findFile.hpp"
//------------------------------------------------------------------------------
ScorePrintout::ScorePrintout(MainFrame *PtToMainFrame, wxString title) : wxPrintout(title)
{
    m_PtToMainFrame = PtToMainFrame;
    m_F2fVerbs = PtToMainFrame->GetF2fVerbs();
}
//------------------------------------------------------------------------------
void ScorePrintout::DrawPageOne()
{
    const wxFont TitleFont(15, wxFONTFAMILY_DECORATIVE, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_BOLD, true);
    const wxFont TexteFont(10, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL);

    wxDC *dc = GetDC();

    FitThisSizeToPage(wxSize(600, 849));

    int w = 0, h = 0, nextObjTop = 20;
    GetPageSizePixels(&w, &h);

        //Img de presentation :
    wxString ImgFileName = findFile(_T("data/printout-header.jpg"));
    if(wxFileExists(ImgFileName))
    {
        wxImage img(ImgFileName, wxBITMAP_TYPE_JPEG);
        dc->DrawBitmap(wxBitmap(img), 68, 20);
        nextObjTop = 20 + img.GetHeight() + 20;
    }
    wxRect labelSize;

    // Titre 1 : "General information :"
    dc->SetFont(TitleFont);

    dc->DrawLabel(_("General information :"), wxBitmap(), wxRect(50, nextObjTop, w - 70, 200), wxALIGN_LEFT | wxALIGN_TOP, -1, &labelSize);
    nextObjTop = labelSize.y + labelSize.height + 10;

    dc->SetFont(TexteFont);

    // Info 1 : "General information :"
    int value = 0;

    if(((m_F2fVerbs->GetTotalVerbsAtBegining() * NB_LEFT_PER_VERB) - m_F2fVerbs->GetTotalLeft()) != 0)
    {
        value = int(double(m_F2fVerbs->GetTotalVerbsAtBegining() * NB_LEFT_PER_VERB - m_F2fVerbs->GetTotalLeft()) / double(m_F2fVerbs->GetTotalVerbsAtBegining() * NB_LEFT_PER_VERB) * double(100));
    }

    wxString labelContent;
    labelContent << _("Different verbs at begining : ") << m_F2fVerbs->GetTotalVerbsAtBegining() << _T(".\n");
    labelContent << _("Verbs at begining : ") << m_F2fVerbs->GetTotalVerbsAtBegining() * NB_LEFT_PER_VERB << _T(".\n");
    labelContent << _("Current number of different verbs : ") << m_F2fVerbs->GetTotalLeft() << _T(".\n");
    labelContent << _("Current number of verbs : ") << m_F2fVerbs->GetTotalVerbs() << _T(".\n");
    labelContent << _("Total errors number : ") << m_F2fVerbs->GetErrorNumber() << _T(".\n");
    labelContent << value << _("% finish.");


    dc->DrawLabel(labelContent, wxBitmap(), wxRect(70, nextObjTop, w - 70, 200), wxALIGN_LEFT | wxALIGN_TOP, -1, &labelSize);

    nextObjTop = labelSize.y + labelSize.height + 20;

    // Titre 2 : " "Statistic :"
    dc->SetFont(TitleFont);

    dc->DrawLabel(_("Statistic :"), wxBitmap(), wxRect(50, nextObjTop, w - 70, 200), wxALIGN_LEFT | wxALIGN_TOP, -1, &labelSize);
    nextObjTop = labelSize.y + labelSize.height + 10;

    dc->SetFont(TexteFont);

    // Info 2 : " "Statistic :"
    labelContent = _T("");
    labelContent << _("Your name : ") << wxString(m_F2fVerbs->GetPupileName().c_str(), wxConvUTF8) << _T(".\n");
    labelContent << _("Your level : ") << wxString(m_F2fVerbs->GetLevel().c_str(), wxConvUTF8) << _T(".\n");
    if(m_F2fVerbs->IsPassword())
    {
        labelContent << _("You are using a password.\n");
    }
    else
    {
        labelContent << _("You are not using a password.\n");
    }

    if(m_F2fVerbs->IsFinish())
    {
        labelContent << _("Time you spend during this session : ") << FormatTimeSpan(wxTimeSpan()) << _T(".\n");
        labelContent << _("Total time you spend : ") << FormatTimeSpan(wxTimeSpan(0,0, m_F2fVerbs->GetWorkDuration())) << _T(".");
    }
    else
    {
        labelContent << _("Time you spend during this session : ") << FormatTimeSpan(wxDateTime::Now() - m_PtToMainFrame->GetBiginWorkDateTime()) << _T(".\n");
        labelContent << _("Total time you spend : ") << FormatTimeSpan((wxDateTime::Now() - m_PtToMainFrame->GetBiginWorkDateTime()) + wxTimeSpan(0,0,m_F2fVerbs->GetWorkDuration())) << _T(".");
    }

    dc->DrawLabel(labelContent, wxBitmap(), wxRect(70, nextObjTop, w - 70, 200), wxALIGN_LEFT | wxALIGN_TOP, -1, &labelSize);
}

//------------------------------------------------------------------------------

wxString ScorePrintout::FormatTimeSpan(wxTimeSpan timeSpan)
{
    wxString str;
    str << timeSpan.GetMinutes() << _(" minutes");
    return str;
}
//------------------------------------------------------------------------------

bool ScorePrintout::OnPrintPage(int page)
{
    wxDC *dc = GetDC();
    if (dc && page == 1)
    {
        if(m_F2fVerbs->IsOk() && !m_F2fVerbs->IsProtected())
        {
            DrawPageOne();
        }
        return true;
    }
    else
    {
        return false;
    }
}
//------------------------------------------------------------------------------

bool ScorePrintout::HasPage(int page)
{
    if(page == 1)
    {
        return true;
    }
    else
    {
        return false;
    }
}
//------------------------------------------------------------------------------

bool ScorePrintout::OnBeginDocument(int startPage, int endPage)
{
    if(m_F2fVerbs->IsOk() && !m_F2fVerbs->IsProtected())
    {
        if(wxPrintout::OnBeginDocument(startPage, endPage))
        {
            return true;
        }
        else
        {
            return false;
        }
    }
    else
    {
        return false;
    }
}
//------------------------------------------------------------------------------

void ScorePrintout::GetPageInfo(int *minPage, int *maxPage, int *selPageFrom, int *selPageTo)
{
    *minPage = 1;
    *maxPage = 1;
    *selPageFrom = 1;
    *selPageTo = 1;
}
//------------------------------------------------------------------------------
